@@ -1,7 +1,7 @@
 ;;; xcb-keysyms.el --- Conversion between  -*- lexical-binding: t -*-
 ;;;                    X keysyms, X keycodes and Emacs key event.
 
-;; Copyright (C) 2015-2019 Free Software Foundation, Inc.
+;; Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
 ;; Author: Chris Feng <chris.w.feng@gmail.com>
 
@@ -39,7 +39,7 @@
 
 ;;; Code:
 
-(eval-when-compile (require 'cl-lib))
+(require 'cl-lib)
 
 (require 'xcb)
 (require 'xcb-xkb)
@@ -149,7 +149,7 @@ This method must be called before using any other method in this module."
                        :autoCtrlsValues 0))))
 
 (cl-defmethod xcb:keysyms:-on-NewKeyboardNotify ((obj xcb:connection) data)
-  "Handle 'NewKeyboardNotify' event."
+  "Handle a \\='NewKeyboardNotify' event."
   (let ((device-id (xcb:-get-extra-plist obj 'keysyms 'device-id))
         (callback (xcb:-get-extra-plist obj 'keysyms 'callback))
         (obj1 (make-instance 'xcb:xkb:NewKeyboardNotify))
@@ -182,7 +182,7 @@ This method must be called before using any other method in this module."
         (funcall callback)))))
 
 (cl-defmethod xcb:keysyms:-on-MapNotify ((obj xcb:connection) data)
-  "Handle 'MapNotify' event."
+  "Handle \\='MapNotify' event."
   (let ((device-id (xcb:-get-extra-plist obj 'keysyms 'device-id))
         (callback (xcb:-get-extra-plist obj 'keysyms 'callback))
         (obj1 (make-instance 'xcb:xkb:MapNotify))
@@ -322,7 +322,7 @@ FIRST-KEYCODE and COUNT specify the keycode range to update."
           xcb:keysyms:shift-lock-mask 0
           xcb:keysyms:num-lock-mask 0)
     (dolist (row (number-sequence 3 7))
-      (let ((mask (lsh 1 row))
+      (let ((mask (ash 1 row))
             (col 0)
             found-alt-or-meta keycode keysym)
         (while (< col keycodes-per-modifier)
@@ -397,12 +397,12 @@ keycode.  The caller is responsible for checking which modifiers to use."
           (throw 'return '(0 . 0)))
         (setq group (if (null modifiers)
                         0
-                      (logand (lsh modifiers -13) #b11))) ;The 13, 14 bits.
+                      (logand (ash modifiers -13) #b11))) ;The 13, 14 bits.
         ;; Wrap group.
         (when (>= group group-number)
           (pcase (logand group-info #xC0) ;See <XKBstr.h>.
             (`xcb:xkb:GroupsWrap:RedirectIntoRange
-             (setq group (logand #xFF (lsh group-info -4))) ;See <XKBstr.h>.
+             (setq group (logand #xFF (ash group-info -4))) ;See <XKBstr.h>.
              ;; Check if it's also out of range.
              (when (>= group group-number)
                (setq group 0)))
@@ -585,10 +585,6 @@ Return 0 if conversion fails."
         ,@(make-list 64 nil)]
   "Emacs event representations of XF86keysym (#x1008ff00 - #x1008ffff).")
 
-(cl-defmethod xcb:keysyms:event->keysym ((obj xcb:connection) event)
-  (declare (obsolete nil "27"))
-  (car (xcb:keysyms:event->keysyms obj event)))
-
 (cl-defmethod xcb:keysyms:event->keysyms ((obj xcb:connection) event)
   "Translate Emacs key event EVENT to list of (keysym . mod-mask).
 
