@@ -1,6 +1,6 @@
 ;;; xcb-types.el --- Type definitions for XCB  -*- lexical-binding: t -*-
 
-;; Copyright (C) 2015-2019 Free Software Foundation, Inc.
+;; Copyright (C) 2015-2024 Free Software Foundation, Inc.
 
 ;; Author: Chris Feng <chris.w.feng@gmail.com>
 
@@ -48,13 +48,15 @@
 
 ;;; Code:
 
-(eval-when-compile (require 'cl-lib))
+(require 'compat)
+(require 'cl-lib) ; cl-coerce
 (require 'cl-generic)
 (require 'eieio)
 (require 'xcb-debug)
 
 (define-minor-mode xcb:debug
-  "Debug-logging enabled if non-nil"
+  "Debug-logging enabled if non-nil."
+  :group 'debug
   :global t)
 
 (defmacro xcb:-log (&optional format-string &rest objects)
@@ -72,52 +74,6 @@ FORMAT-STRING is a string specifying the message to output, as in
                         ,@objects)
      nil))
 
-;;;; Fix backward compatibility issues with Emacs 24
-
-(eval-and-compile
-  (when (< emacs-major-version 25)
-    ;; Copied from Emacs 25 with documentation and comments stripped.
-    ;; The version of `with-slots' in Emacs 24 is buggy and inefficient.
-    (defmacro with-slots (spec-list object &rest body)
-      (declare (indent 2) (debug (sexp sexp def-body)))
-      (require 'cl-lib)
-      (macroexp-let2 nil object object
-        `(cl-symbol-macrolet
-             ,(mapcar (lambda (entry)
-                        (let ((var  (if (listp entry) (car entry) entry))
-                              (slot (if (listp entry) (cadr entry) entry)))
-                          (list var `(slot-value ,object ',slot))))
-                      spec-list)
-           ,@body)))))
-
-;; Backport some functions to Emacs 24
-
-(eval-and-compile
-  (unless (fboundp 'eieio-class-slots)
-    (defun eieio-class-slots (class)
-      (let* ((tmp (get class 'eieio-class-definition))
-             (names (aref tmp 5))
-             (initforms (aref tmp 6))
-             (types (aref tmp 8))
-             result)
-        (dotimes (i (length names))
-          (setq result (nconc result (list (vector (elt names i)
-                                                   (elt initforms i)
-                                                   (elt types i))))))
-        result))))
-
-(eval-and-compile
-  (unless (fboundp 'eieio-slot-descriptor-name)
-    (defsubst eieio-slot-descriptor-name (slot) (aref slot 0))))
-
-(eval-and-compile
-  (unless (fboundp 'cl--slot-descriptor-initform)
-    (defsubst cl--slot-descriptor-initform (slot) (aref slot 1))))
-
-(eval-when-compile
-  (unless (fboundp 'cl--slot-descriptor-type)
-    (defsubst cl--slot-descriptor-type (slot) (aref slot 2))))
-
 ;;;; Utility functions
 
 (defsubst xcb:-pack-u1 (value)
@@ -131,11 +87,11 @@ FORMAT-STRING is a string specifying the message to output, as in
 
 (defsubst xcb:-pack-u2 (value)
   "2 bytes unsigned integer => byte array (MSB first)."
-  (vector (logand (lsh value -8) #xFF) (logand value #xFF)))
+  (vector (logand (ash value -8) #xFF) (logand value #xFF)))
 
 (defsubst xcb:-pack-u2-lsb (value)
   "2 bytes unsigned integer => byte array (LSB first)."
-  (vector (logand value #xFF) (logand (lsh value -8) #xFF)))
+  (vector (logand value #xFF) (logand (ash value -8) #xFF)))
 
 (defsubst xcb:-pack-i2 (value)
   "2 bytes signed integer => byte array (MSB first)."
@@ -150,82 +106,82 @@ FORMAT-STRING is a string specifying the message to output, as in
 ;; Due to loss of significance of floating-point numbers, `xcb:-pack-u8' and
 ;; `xcb:-pack-u8-lsb' may return approximate results.
 (eval-and-compile
-  (if (/= 0 (lsh 1 32))
+  (if (/= 0 (ash 1 32))
       ;; 64 bit
       (progn
         (defsubst xcb:-pack-u4 (value)
           "4 bytes unsigned integer => byte array (MSB first, 64-bit)."
-          (vector (logand (lsh value -24) #xFF) (logand (lsh value -16) #xFF)
-                  (logand (lsh value -8) #xFF) (logand value #xFF)))
+          (vector (logand (ash value -24) #xFF) (logand (ash value -16) #xFF)
+                  (logand (ash value -8) #xFF) (logand value #xFF)))
         (defsubst xcb:-pack-u4-lsb (value)
           "4 byte unsigned integer => byte array (LSB first, 64-bit)."
           (vector (logand value #xFF)
-                  (logand (lsh value -8) #xFF)
-                  (logand (lsh value -16) #xFF)
-                  (logand (lsh value -24) #xFF)))
+                  (logand (ash value -8) #xFF)
+                  (logand (ash value -16) #xFF)
+                  (logand (ash value -24) #xFF)))
         (defsubst xcb:-pack-u8 (value)
           "8 bytes unsigned integer => byte array (MSB first)."
           (if (integerp value)
-              (vector (logand (lsh value -56) #xFF)
-                      (logand (lsh value -48) #xFF)
-                      (logand (lsh value -40) #xFF)
-                      (logand (lsh value -32) #xFF)
-                      (logand (lsh value -24) #xFF)
-                      (logand (lsh value -16) #xFF)
-                      (logand (lsh value -8) #xFF)
+              (vector (logand (ash value -56) #xFF)
+                      (logand (ash value -48) #xFF)
+                      (logand (ash value -40) #xFF)
+                      (logand (ash value -32) #xFF)
+                      (logand (ash value -24) #xFF)
+                      (logand (ash value -16) #xFF)
+                      (logand (ash value -8) #xFF)
                       (logand value #xFF))
             (let* ((msdw (min 4294967295. (truncate value 4294967296.)))
                    (lsdw (min 4294967295.
                               (truncate (- value (* msdw 4294967296.0))))))
-              (vector (logand (lsh msdw -24) #xFF) (logand (lsh msdw -16) #xFF)
-                      (logand (lsh msdw -8) #xFF) (logand msdw #xFF)
-                      (logand (lsh lsdw -24) #xFF) (logand (lsh lsdw -16) #xFF)
-                      (logand (lsh lsdw -8) #xFF) (logand lsdw #xFF)))))
+              (vector (logand (ash msdw -24) #xFF) (logand (ash msdw -16) #xFF)
+                      (logand (ash msdw -8) #xFF) (logand msdw #xFF)
+                      (logand (ash lsdw -24) #xFF) (logand (ash lsdw -16) #xFF)
+                      (logand (ash lsdw -8) #xFF) (logand lsdw #xFF)))))
         (defsubst xcb:-pack-u8-lsb (value)
           "8 bytes unsigned integer => byte array (LSB first)."
           (if (integerp value)
               (vector (logand value #xFF)
-                      (logand (lsh value -8) #xFF)
-                      (logand (lsh value -16) #xFF)
-                      (logand (lsh value -24) #xFF)
-                      (logand (lsh value -32) #xFF)
-                      (logand (lsh value -40) #xFF)
-                      (logand (lsh value -48) #xFF)
-                      (logand (lsh value -56) #xFF))
+                      (logand (ash value -8) #xFF)
+                      (logand (ash value -16) #xFF)
+                      (logand (ash value -24) #xFF)
+                      (logand (ash value -32) #xFF)
+                      (logand (ash value -40) #xFF)
+                      (logand (ash value -48) #xFF)
+                      (logand (ash value -56) #xFF))
             (let* ((msdw (min 4294967295. (truncate value 4294967296.)))
                    (lsdw (min 4294967295.
                               (truncate (- value (* msdw 4294967296.0))))))
-              (vector (logand lsdw #xFF) (logand (lsh lsdw -8) #xFF)
-                      (logand (lsh lsdw -16) #xFF) (logand (lsh lsdw -24) #xFF)
+              (vector (logand lsdw #xFF) (logand (ash lsdw -8) #xFF)
+                      (logand (ash lsdw -16) #xFF) (logand (ash lsdw -24) #xFF)
                       (logand msdw #xFF)
-                      (logand (lsh msdw -8) #xFF)
-                      (logand (lsh msdw -16) #xFF)
-                      (logand (lsh msdw -24) #xFF))))))
+                      (logand (ash msdw -8) #xFF)
+                      (logand (ash msdw -16) #xFF)
+                      (logand (ash msdw -24) #xFF))))))
     ;; 32 bit (30-bit actually; large numbers are represented as float type)
     (defsubst xcb:-pack-u4 (value)
       "4 bytes unsigned integer => byte array (MSB first, 32-bit)."
       (if (integerp value)
-          (vector (logand (lsh value -24) #xFF) (logand (lsh value -16) #xFF)
-                  (logand (lsh value -8) #xFF) (logand value #xFF))
+          (vector (logand (ash value -24) #xFF) (logand (ash value -16) #xFF)
+                  (logand (ash value -8) #xFF) (logand value #xFF))
         (let* ((msw (truncate value #x10000))
                (lsw (truncate (- value (* msw 65536.0)))))
-          (vector (logand (lsh msw -8) #xFF) (logand msw #xFF)
-                  (logand (lsh lsw -8) #xFF) (logand lsw #xFF)))))
+          (vector (logand (ash msw -8) #xFF) (logand msw #xFF)
+                  (logand (ash lsw -8) #xFF) (logand lsw #xFF)))))
     (defsubst xcb:-pack-u4-lsb (value)
       "4 bytes unsigned integer => byte array (LSB first, 32-bit)."
       (if (integerp value)
-          (vector (logand value #xFF) (logand (lsh value -8) #xFF)
-                  (logand (lsh value -16) #xFF) (logand (lsh value -24) #xFF))
+          (vector (logand value #xFF) (logand (ash value -8) #xFF)
+                  (logand (ash value -16) #xFF) (logand (ash value -24) #xFF))
         (let* ((msw (truncate value #x10000))
                (lsw (truncate (- value (* msw 65536.0)))))
-          (vector (logand lsw #xFF) (logand (lsh lsw -8) #xFF)
-                  (logand msw #xFF) (logand (lsh msw -8) #xFF)))))
+          (vector (logand lsw #xFF) (logand (ash lsw -8) #xFF)
+                  (logand msw #xFF) (logand (ash msw -8) #xFF)))))
     (defsubst xcb:-pack-u8 (value)
       "8 bytes unsigned integer => byte array (MSB first, 32-bit)."
       (if (integerp value)
           (vector 0 0 0 0
-                  (logand (lsh value -24) #xFF) (logand (lsh value -16) #xFF)
-                  (logand (lsh value -8) #xFF) (logand value #xFF))
+                  (logand (ash value -24) #xFF) (logand (ash value -16) #xFF)
+                  (logand (ash value -8) #xFF) (logand value #xFF))
         (let* ((msw (min #xFFFF (truncate value 281474976710656.)))
                (w1 (min #xFFFF
                         (truncate (setq value
@@ -235,15 +191,15 @@ FORMAT-STRING is a string specifying the message to output, as in
                         (truncate (setq value (- value (* w1 4294967296.0)))
                                   #x10000)))
                (lsw (min #xFFFF (truncate (- value (* w2 65536.0))))))
-          (vector (logand (lsh msw -8) #xFF) (logand msw #xFF)
-                  (logand (lsh w1 -8) #xFF) (logand w1 #xFF)
-                  (logand (lsh w2 -8) #xFF) (logand w2 #xFF)
-                  (logand (lsh lsw -8) #xFF) (logand lsw #xFF)))))
+          (vector (logand (ash msw -8) #xFF) (logand msw #xFF)
+                  (logand (ash w1 -8) #xFF) (logand w1 #xFF)
+                  (logand (ash w2 -8) #xFF) (logand w2 #xFF)
+                  (logand (ash lsw -8) #xFF) (logand lsw #xFF)))))
     (defsubst xcb:-pack-u8-lsb (value)
       "8 bytes unsigned integer => byte array (LSB first, 32-bit)."
       (if (integerp value)
-          (vector (logand value #xFF) (logand (lsh value -8) #xFF)
-                  (logand (lsh value -16) #xFF) (logand (lsh value -24) #xFF)
+          (vector (logand value #xFF) (logand (ash value -8) #xFF)
+                  (logand (ash value -16) #xFF) (logand (ash value -24) #xFF)
                   0 0 0 0)
         (let* ((msw (min #xFFFF (truncate value 281474976710656.)))
                (w1 (min #xFFFF
@@ -254,10 +210,10 @@ FORMAT-STRING is a string specifying the message to output, as in
                         (truncate (setq value (- value (* w1 4294967296.0)))
                                   #x10000)))
                (lsw (min #xFFFF (truncate (- value (* w2 65536.0))))))
-          (vector (logand lsw #xFF) (logand (lsh lsw -8) #xFF)
-                  (logand w2 #xFF) (logand (lsh w2 -8) #xFF)
-                  (logand w1 #xFF) (logand (lsh w1 -8) #xFF)
-                  (logand msw #xFF) (logand (lsh msw -8) #xFF)))))))
+          (vector (logand lsw #xFF) (logand (ash lsw -8) #xFF)
+                  (logand w2 #xFF) (logand (ash w2 -8) #xFF)
+                  (logand w1 #xFF) (logand (ash w1 -8) #xFF)
+                  (logand msw #xFF) (logand (ash msw -8) #xFF)))))))
 
 (defsubst xcb:-pack-i4 (value)
   "4 bytes signed integer => byte array (MSB first)."
@@ -284,11 +240,11 @@ FORMAT-STRING is a string specifying the message to output, as in
 
 (defsubst xcb:-unpack-u2 (data offset)
   "Byte array => 2 bytes unsigned integer (MSB first)."
-  (logior (lsh (aref data offset) 8) (aref data (1+ offset))))
+  (logior (ash (aref data offset) 8) (aref data (1+ offset))))
 
 (defsubst xcb:-unpack-u2-lsb (data offset)
   "Byte array => 2 bytes unsigned integer (LSB first)."
-  (logior (aref data offset) (lsh (aref data (1+ offset)) 8)))
+  (logior (aref data offset) (ash (aref data (1+ offset)) 8)))
 
 (defsubst xcb:-unpack-i2 (data offset)
   "Byte array => 2 bytes signed integer (MSB first)."
@@ -307,55 +263,55 @@ FORMAT-STRING is a string specifying the message to output, as in
 ;; Due to loss of significance of floating-point numbers, `xcb:-unpack-u8' and
 ;; `xcb:-unpack-u8-lsb' may return approximate results.
 (eval-and-compile
-  (if (/= 0 (lsh 1 32))
+  (if (/= 0 (ash 1 32))
       ;; 64-bit
       (progn
         (defsubst xcb:-unpack-u4 (data offset)
           "Byte array => 4 bytes unsigned integer (MSB first, 64-bit)."
-          (logior (lsh (aref data offset) 24) (lsh (aref data (1+ offset)) 16)
-                  (lsh (aref data (+ offset 2)) 8) (aref data (+ offset 3))))
+          (logior (ash (aref data offset) 24) (ash (aref data (1+ offset)) 16)
+                  (ash (aref data (+ offset 2)) 8) (aref data (+ offset 3))))
         (defsubst xcb:-unpack-u4-lsb (data offset)
           "Byte array => 4 bytes unsigned integer (LSB first, 64-bit)."
-          (logior (aref data offset) (lsh (aref data (1+ offset)) 8)
-                  (lsh (aref data (+ offset 2)) 16)
-                  (lsh (aref data (+ offset 3)) 24)))
+          (logior (aref data offset) (ash (aref data (1+ offset)) 8)
+                  (ash (aref data (+ offset 2)) 16)
+                  (ash (aref data (+ offset 3)) 24)))
         (defsubst xcb:-unpack-u8 (data offset)
           "Byte array => 8 bytes unsigned integer (MSB first)."
           (let ((msb (aref data offset)))
-            (+ (if (> msb 31) (* msb 72057594037927936.0) (lsh msb 56))
-               (logior (lsh (aref data (1+ offset)) 48)
-                       (lsh (aref data (+ offset 2)) 40)
-                       (lsh (aref data (+ offset 3)) 32)
-                       (lsh (aref data (+ offset 4)) 24)
-                       (lsh (aref data (+ offset 5)) 16)
-                       (lsh (aref data (+ offset 6)) 8)
+            (+ (if (> msb 31) (* msb 72057594037927936.0) (ash msb 56))
+               (logior (ash (aref data (1+ offset)) 48)
+                       (ash (aref data (+ offset 2)) 40)
+                       (ash (aref data (+ offset 3)) 32)
+                       (ash (aref data (+ offset 4)) 24)
+                       (ash (aref data (+ offset 5)) 16)
+                       (ash (aref data (+ offset 6)) 8)
                        (aref data (+ offset 7))))))
         (defsubst xcb:-unpack-u8-lsb (data offset)
           "Byte array => 8 bytes unsigned integer (LSB first)."
           (let ((msb (aref data (+ offset 7))))
-            (+ (if (> msb 31) (* msb 72057594037927936.0) (lsh msb 56))
-               (logior (lsh (aref data (+ offset 6)) 48)
-                       (lsh (aref data (+ offset 5)) 40)
-                       (lsh (aref data (+ offset 4)) 32)
-                       (lsh (aref data (+ offset 3)) 24)
-                       (lsh (aref data (+ offset 2)) 16)
-                       (lsh (aref data (1+ offset)) 8)
+            (+ (if (> msb 31) (* msb 72057594037927936.0) (ash msb 56))
+               (logior (ash (aref data (+ offset 6)) 48)
+                       (ash (aref data (+ offset 5)) 40)
+                       (ash (aref data (+ offset 4)) 32)
+                       (ash (aref data (+ offset 3)) 24)
+                       (ash (aref data (+ offset 2)) 16)
+                       (ash (aref data (1+ offset)) 8)
                        (aref data offset))))))
     ;; 32-bit (30-bit actually; large numbers are represented as float type)
     (defsubst xcb:-unpack-u4 (data offset)
       "Byte array => 4 bytes unsigned integer (MSB first, 32-bit)."
       (let ((msb (aref data offset)))
-        (+ (if (> msb 31) (* msb 16777216.0) (lsh msb 24))
-           (logior (lsh (aref data (1+ offset)) 16)
-                   (lsh (aref data (+ offset 2)) 8)
+        (+ (if (> msb 31) (* msb 16777216.0) (ash msb 24))
+           (logior (ash (aref data (1+ offset)) 16)
+                   (ash (aref data (+ offset 2)) 8)
                    (aref data (+ offset 3))))))
     (defsubst xcb:-unpack-u4-lsb (data offset)
       "Byte array => 4 bytes unsigned integer (LSB first, 32-bit)."
       (let ((msb (aref data (+ offset 3))))
-        (+ (if (> msb 31) (* msb 16777216.0) (lsh msb 24))
+        (+ (if (> msb 31) (* msb 16777216.0) (ash msb 24))
            (logior (aref data offset)
-                   (lsh (aref data (1+ offset)) 8)
-                   (lsh (aref data (+ offset 2)) 16)))))
+                   (ash (aref data (1+ offset)) 8)
+                   (ash (aref data (+ offset 2)) 16)))))
     (defsubst xcb:-unpack-u8 (data offset)
       "Byte array => 8 bytes unsigned integer (MSB first, 32-bit)."
       (+ (* (aref data offset) 72057594037927936.0)
@@ -363,8 +319,8 @@ FORMAT-STRING is a string specifying the message to output, as in
          (* (aref data (+ offset 2)) 1099511627776.0)
          (* (aref data (+ offset 3)) 4294967296.0)
          (* (aref data (+ offset 4)) 16777216.0)
-         (logior (lsh (aref data (+ offset 5)) 16)
-                 (lsh (aref data (+ offset 6)) 8)
+         (logior (ash (aref data (+ offset 5)) 16)
+                 (ash (aref data (+ offset 6)) 8)
                  (aref data (+ offset 7)))))
     (defsubst xcb:-unpack-u8-lsb (data offset)
       "Byte array => 8 bytes unsigned integer (LSB first, 32-bit)."
@@ -373,8 +329,8 @@ FORMAT-STRING is a string specifying the message to output, as in
          (* (aref data (+ offset 5)) 1099511627776.0)
          (* (aref data (+ offset 4)) 4294967296.0)
          (* (aref data (+ offset 3)) 16777216.0)
-         (logior (lsh (aref data (+ offset 2)) 16)
-                 (lsh (aref data (1+ offset)) 8)
+         (logior (ash (aref data (+ offset 2)) 16)
+                 (ash (aref data (1+ offset)) 8)
                  (aref data offset))))))
 
 (defsubst xcb:-unpack-i4 (data offset)
@@ -391,6 +347,65 @@ FORMAT-STRING is a string specifying the message to output, as in
         value
       (- value 4294967296.))))          ;treated as float for 32-bit
 
+(defsubst xcb:-f64-to-binary64 (value)
+  "Encode a 64-bit float VALUE as a binary64 (IEEE 754)."
+  (let* ((sigexp (frexp value))
+         (exp (+ (cdr sigexp) 1022))
+         (frac (abs (car sigexp)))
+         (isneg (< (copysign 1.0 (car sigexp)) 0)) ; use `copysign' to detect -0.0
+         (signmask (if isneg #x8000000000000000 0)))
+    (+ (cond ((zerop frac) 0)                                          ; 0
+             ((isnan frac) #xff0000000000001)                          ; NaN
+             ((or (>= exp 2047) (= frac 1e+INF)) #x7ff0000000000000)   ; Inf
+             ((<= exp 0) (ash (round (ldexp frac 52)) exp))            ; Subnormal
+             (t (+ (ash exp 52) (logand #xfffffffffffff
+                                        (round (ldexp frac 53))))))    ; Normal
+       signmask)))
+
+(defsubst xcb:-f32-to-binary32 (value)
+  "Encode a 32-bit float VALUE as a binary32 (IEEE 754)."
+  (let* ((sigexp (frexp value))
+         (exp (+ (cdr sigexp) 126))
+         (frac (abs (car sigexp)))
+         (isneg (< (copysign 1.0 (car sigexp)) 0)) ; use `copysign' to detect -0.0
+         (signmask (if isneg #x80000000 0)))
+    (+ (cond ((zerop frac) 0)                                                ; 0
+             ((isnan frac) #x7f800001)                                       ; NaN
+             ((or (>= exp 255) (= frac 1e+INF)) #x7f800000)                  ; Inf
+             ((<= exp 0) (ash (round (ldexp frac 23)) exp))                  ; Subnormal
+             (t (+ (ash exp 23) (logand #x7fffff (round (ldexp frac 24)))))) ; Normal
+       signmask)))
+
+(defsubst xcb:-binary64-to-f64 (value)
+  "Decode binary64 VALUE into a float."
+  (let ((sign (pcase (ash value -63)
+                (0 +0.0)
+                (1 -0.0)
+                (_ (error "[XCB] Value too large for a float64: %d" value))))
+        (exp (logand 2047 (ash value -52)))
+        (frac (logand #xfffffffffffff value)))
+    (copysign ; Use copysign, not multiplication, to deal with +/- NAN.
+     (pcase exp
+       (2047 (if (zerop frac) 1e+INF 1e+NaN))                 ; INF/NAN
+       (0    (ldexp frac -1074))                              ; Subnormal
+       (_    (ldexp (+ #x10000000000000 frac) (- exp 1075)))) ; Normal
+     sign)))
+
+(defsubst xcb:-binary32-to-f32 (value)
+  "Decode binary32 VALUE into a float."
+  (let ((sign (pcase (ash value -31)
+                (0 +0.0)
+                (1 -0.0)
+                (_ (error "[XCB] Value too large for a float32: %d" value))))
+        (exp (logand 255 (ash value -23)))
+        (frac (logand #x7fffff value)))
+    (copysign ; Use copysign, not multiplication, to deal with +/- NAN.
+     (pcase exp
+       (255 (if (zerop frac) 1e+INF 1e+NaN))        ; INF/NAN
+       (0   (ldexp frac -149))                      ; Subnormal
+       (_   (ldexp (+ #x800000 frac) (- exp 150)))) ; Normal
+     sign)))
+
 (defmacro xcb:-fieldref (field)
   "Evaluate a <fieldref> field."
   `(slot-value obj ,field))
@@ -399,13 +414,6 @@ FORMAT-STRING is a string specifying the message to output, as in
   "Evaluate a <paramref> field."
   `(slot-value ctx ,field))
 
-(defsubst xcb:-popcount (mask)
-  "Return the popcount of integer MASK."
-  (apply #'+ (mapcar (lambda (i)
-                       (logand (lsh mask i) 1))
-                     ;; 32-bit number assumed (CARD32)
-                     (eval-when-compile (number-sequence -31 0)))))
-
 (defsubst xcb:-request-class->reply-class (request)
   "Return the reply class corresponding to the request class REQUEST."
   (intern-soft (concat (symbol-name request) "~reply")))
@@ -416,8 +424,8 @@ FORMAT-STRING is a string specifying the message to output, as in
 (defmacro xcb:deftypealias (new-type old-type)
   "Define NEW-TYPE as an alias of type OLD-TYPE.
 
-Also the fundamental type is stored in 'the xcb--typealias' variable
-property (for internal use only)."
+Also the fundamental type is stored in the `xcb--typealias'
+variable property (for internal use only)."
   `(progn
      ;; FIXME: `new-type' should probably just not be eval'd at all,
      ;; but that requires changing all callers not to quote their arg.
@@ -434,6 +442,9 @@ property (for internal use only)."
 (cl-deftype xcb:-u4 () t)
 ;; 8 B unsigned integer
 (cl-deftype xcb:-u8 () t)
+;; floats & doubles
+(cl-deftype xcb:-f32 () t)
+(cl-deftype xcb:-f64 () t)
 ;; <pad>
 (cl-deftype xcb:-pad () t)
 ;; <pad> with align attribute
@@ -458,6 +469,8 @@ property (for internal use only)."
 (xcb:deftypealias 'xcb:CARD32 'xcb:-u4)
 (xcb:deftypealias 'xcb:CARD64 'xcb:-u8)
 (xcb:deftypealias 'xcb:BOOL 'xcb:-u1)
+(xcb:deftypealias 'xcb:float 'xcb:-f32)
+(xcb:deftypealias 'xcb:double 'xcb:-f64)
 
 ;;;; Struct type
 
@@ -479,7 +492,8 @@ Consider let-bind it rather than change its global value."))
 (defclass xcb:-struct (xcb:--struct)
   ((~lsb :initarg :~lsb
          :initform (symbol-value 'xcb:lsb) ;see `eieio-default-eval-maybe'
-         :type xcb:-ignore))
+         :type xcb:-ignore)
+   (~size :initform nil :type xcb:-ignore))
   :documentation "Struct type.")
 
 (cl-defmethod xcb:marshal ((obj xcb:-struct))
@@ -499,6 +513,14 @@ Consider let-bind it rather than change its global value."))
                                                     (length result))))
           (when (eq type 'xcb:-switch) ;xcb:-switch always finishes a struct
             (throw 'break 'nil)))))
+    ;; If we specify a size, verify that it matches the actual size.
+    (when-let* ((size-exp (slot-value obj '~size))
+                (size (eval size-exp `((obj . ,obj)))))
+      (unless (length= result size)
+        (error "[XCB] Unexpected size for type %s: got %d, expected %d"
+               (type-of obj)
+               (length result)
+               size)))
     result))
 
 (cl-defmethod xcb:-marshal-field ((obj xcb:-struct) type value &optional pos)
@@ -520,6 +542,12 @@ The optional POS argument indicates current byte index of the field (used by
      (if (slot-value obj '~lsb) (xcb:-pack-i4-lsb value) (xcb:-pack-i4 value)))
     (`xcb:-u8
      (if (slot-value obj '~lsb) (xcb:-pack-u8-lsb value) (xcb:-pack-u8 value)))
+    (`xcb:-f32
+     (let ((value (xcb:-f32-to-binary32 value)))
+       (if (slot-value obj '~lsb) (xcb:-pack-u4-lsb value) (xcb:-pack-u4 value))))
+    (`xcb:-f64
+     (let ((value (xcb:-f64-to-binary64 value)))
+       (if (slot-value obj '~lsb) (xcb:-pack-u8-lsb value) (xcb:-pack-u8 value))))
     (`xcb:void (vector value))
     (`xcb:-pad
      (unless (integerp value)
@@ -545,7 +573,14 @@ The optional POS argument indicates current byte index of the field (used by
          (unless list-size
            (setq list-size (length data)))) ;list-size can be nil
        (cl-assert (= list-size (length data)))
-       (mapconcat (lambda (i) (xcb:-marshal-field obj list-type i)) data [])))
+       ;; The data may be large, and if it's a string that's supposed
+       ;; to be converted to a vector of bytes, then the transform can
+       ;; be done trivially and much faster by just coercing.
+       (if (and (eq list-type 'xcb:BYTE)
+		(eq (type-of data) 'string))
+	   (cl-coerce data 'vector)
+	 (mapconcat (lambda (i) (xcb:-marshal-field obj list-type i))
+		    data []))))
     (`xcb:-switch
      (let ((slots (eieio-class-slots (eieio-object-class obj)))
            (expression (plist-get value 'expression))
@@ -599,14 +634,27 @@ The optional argument CTX is for <paramref>."
         (setq type (cl--slot-descriptor-type slot))
         (unless (eq type 'xcb:-ignore)
           (setq slot-name (eieio-slot-descriptor-name slot)
-                tmp (xcb:-unmarshal-field obj type byte-array 0
+                tmp (xcb:-unmarshal-field obj type byte-array result
                                           (eieio-oref-default obj slot-name)
                                           ctx total-length))
           (setf (slot-value obj slot-name) (car tmp))
-          (setq byte-array (substring byte-array (cadr tmp)))
           (setq result (+ result (cadr tmp)))
           (when (eq type 'xcb:-switch) ;xcb:-switch always finishes a struct
             (throw 'break 'nil)))))
+    ;; Let the struct compute it's size if a length field is specified. This lets us skip unknown
+    ;; fields.
+    (when-let* ((size-exp (slot-value obj '~size))
+                (size (eval size-exp `((obj . ,obj)))))
+      ;; Make sure the stated size is reasonable.
+      (cond
+       ((< size result)
+        (error "[XCB] Object of type `%s' specified a size (%d) less than the number of bytes read (%d)"
+               (type-of obj) size result))
+       ((length< byte-array (- size result))
+        (error "[XCB] Object of type `%s' specified a size (%d) greater than the size of the input (%d)"
+               (type-of obj) size (+ result (length byte-array)))))
+      ;; Skip any additional bytes.
+      (setq result size))
     result))
 
 (cl-defmethod xcb:-unmarshal-field ((obj xcb:-struct) type data offset
@@ -642,6 +690,16 @@ and the second the consumed length."
                         (xcb:-unpack-u8-lsb data offset)
                       (xcb:-unpack-u8 data offset))
                     8))
+    (`xcb:-f32 (list (xcb:-binary32-to-f32
+                      (if (slot-value obj '~lsb)
+                          (xcb:-unpack-u4-lsb data offset)
+                        (xcb:-unpack-u4 data offset)))
+                      4))
+    (`xcb:-f64 (list (xcb:-binary64-to-f64
+                      (if (slot-value obj '~lsb)
+                          (xcb:-unpack-u8-lsb data offset)
+                        (xcb:-unpack-u8 data offset)))
+                      8))
     (`xcb:void (list (aref data offset) 1))
     (`xcb:-pad
      (unless (integerp initform)
@@ -720,12 +778,11 @@ and the second the consumed length."
                    (setq slot-type (cl--slot-descriptor-type slot))
                    (throw 'break nil))))
              (unless (eq slot-type 'xcb:-ignore)
-               (setq tmp (xcb:-unmarshal-field obj slot-type data offset
+               (setq tmp (xcb:-unmarshal-field obj slot-type data (+ offset count)
                                                (eieio-oref-default obj name)
                                                nil total-length))
                (setf (slot-value obj name) (car tmp))
-               (setq count (+ count (cadr tmp)))
-               (setq data (substring data (cadr tmp)))))))
+               (setq count (+ count (cadr tmp)))))))
        (list initform count)))
     ((and x (guard (child-of-class-p x 'xcb:-struct)))
      (let* ((struct-obj (make-instance x))
@@ -748,7 +805,7 @@ and the second the consumed length."
   ((~code :type xcb:-u1))
   :documentation "Event type.")
 ;; Implemented in 'xcb.el'
-(cl-defgeneric xcb:-error-or-event-class->number ((obj xcb:connection) class))
+(cl-defgeneric xcb:-error-or-event-class->number (obj class))
 ;;
 (cl-defmethod xcb:marshal ((obj xcb:-event) connection &optional sequence)
   "Return the byte-array representation of event OBJ.
@@ -821,8 +878,12 @@ This result is converted from the first bounded slot."
                                       (slot-value obj name)))
         (when (> (length tmp) (length result))
           (setq result tmp))))
-    (when (> size (length result))
+    (cond
+     ((length< result size)
       (setq result (vconcat result (make-vector (- size (length result)) 0))))
+     ((length> result size)
+      (error "[XCB] Marshaled enum `%s' is larger than its declared size (%d > %d)"
+             (type-of obj) (length result) size)))
     result))
 ;;
 (cl-defmethod xcb:unmarshal ((obj xcb:-union) byte-array &optional ctx
